@@ -2,7 +2,7 @@ from pypeta import Peta
 import sys
 
 host = 'https://peta.bgi.com/api'
-peta = Peta(username="bgi-peta@genomics.cn", password="zhuqingyan", host=host)
+peta = Peta(username="liujilong@bgi.com", password="liujilong", host=host)
 
 studys = peta.list_visible_studys()
 target_name = sys.argv[1]
