@@ -1,6 +1,6 @@
 from pypeta import Peta
 
 host='https://peta.bgi.com/api'
-peta=Peta(username="bgi-peta@genomics.cn",password="zhuqingyan",host=host)
+peta=Peta(username="liujilong@bgi.com",password="liujilong",host=host)
 
-print(peta.cookies['token'])
\ No newline at end of file
+print(peta.cookies['token'])
